==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1NodeSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSpecFluent<A extends V1NodeSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfigSource instead.
 * @return The buildable object.
 */
@Deprecated public V1NodeConfigSource getConfigSource();
    public V1NodeConfigSource buildConfigSource();
    public A withConfigSource(V1NodeConfigSource configSource);
    public Boolean hasConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> withNewConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> withNewConfigSourceLike(V1NodeConfigSource item);
    public V1NodeSpecFluent.ConfigSourceNested<A> editConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSourceLike(V1NodeConfigSource item);
    public String getExternalID();
    public A withExternalID(String externalID);
    public Boolean hasExternalID();
    public String getPodCIDR();
    public A withPodCIDR(String podCIDR);
    public Boolean hasPodCIDR();
    public String getProviderID();
    public A withProviderID(String providerID);
    public Boolean hasProviderID();
    public A addToTaints(int index,V1Taint item);
    public A setToTaints(int index,V1Taint item);
    public A addToTaints(V1Taint... items);
    public A addAllToTaints(Collection<V1Taint> items);
    public A removeFromTaints(V1Taint... items);
    public A removeAllFromTaints(Collection<V1Taint> items);
    
/**
 * This method has been deprecated, please use method buildTaints instead.
 * @return The buildable object.
 */
@Deprecated public List<V1Taint> getTaints();
    public List<V1Taint> buildTaints();
    public V1Taint buildTaint(int index);
    public V1Taint buildFirstTaint();
    public V1Taint buildLastTaint();
    public V1Taint buildMatchingTaint(io.kubernetes.client.fluent.Predicate<V1TaintBuilder> predicate);
    public A withTaints(List<V1Taint> taints);
    public A withTaints(V1Taint... taints);
    public Boolean hasTaints();
    public V1NodeSpecFluent.TaintsNested<A> addNewTaint();
    public V1NodeSpecFluent.TaintsNested<A> addNewTaintLike(V1Taint item);
    public V1NodeSpecFluent.TaintsNested<A> setNewTaintLike(int index,V1Taint item);
    public V1NodeSpecFluent.TaintsNested<A> editTaint(int index);
    public V1NodeSpecFluent.TaintsNested<A> editFirstTaint();
    public V1NodeSpecFluent.TaintsNested<A> editLastTaint();
    public V1NodeSpecFluent.TaintsNested<A> editMatchingTaint(io.kubernetes.client.fluent.Predicate<V1TaintBuilder> predicate);
    public Boolean isUnschedulable();
    public A withUnschedulable(Boolean unschedulable);
    public Boolean hasUnschedulable();
    public A withNewUnschedulable(boolean arg1);
    public A withNewUnschedulable(String arg1);

    public interface ConfigSourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeConfigSourceFluent<V1NodeSpecFluent.ConfigSourceNested<N>>{

        
    public N and();    public N endConfigSource();
}
    public interface TaintsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TaintFluent<V1NodeSpecFluent.TaintsNested<N>>{

        
    public N and();    public N endTaint();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NodeSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSpecFluent<A extends V1NodeSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfigSource instead.
 * @return The buildable object.
 */
@Deprecated public V1NodeConfigSource getConfigSource();
    public V1NodeConfigSource buildConfigSource();
    public A withConfigSource(V1NodeConfigSource configSource);
    public Boolean hasConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> withNewConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> withNewConfigSourceLike(V1NodeConfigSource item);
    public V1NodeSpecFluent.ConfigSourceNested<A> editConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSource();
    public V1NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSourceLike(V1NodeConfigSource item);
    public String getExternalID();
    public A withExternalID(String externalID);
    public Boolean hasExternalID();
    public A withNewExternalID(String arg1);
    public A withNewExternalID(StringBuilder arg1);
    public A withNewExternalID(StringBuffer arg1);
    public String getPodCIDR();
    public A withPodCIDR(String podCIDR);
    public Boolean hasPodCIDR();
    public A withNewPodCIDR(String arg1);
    public A withNewPodCIDR(StringBuilder arg1);
    public A withNewPodCIDR(StringBuffer arg1);
    public String getProviderID();
    public A withProviderID(String providerID);
    public Boolean hasProviderID();
    public A withNewProviderID(String arg1);
    public A withNewProviderID(StringBuilder arg1);
    public A withNewProviderID(StringBuffer arg1);
    public A addToTaints(int index,V1Taint item);
    public A setToTaints(int index,V1Taint item);
    public A addToTaints(V1Taint... items);
    public A addAllToTaints(Collection<V1Taint> items);
    public A removeFromTaints(V1Taint... items);
    public A removeAllFromTaints(Collection<V1Taint> items);
    
/**
 * This method has been deprecated, please use method buildTaints instead.
 * @return The buildable object.
 */
@Deprecated public List<V1Taint> getTaints();
    public List<V1Taint> buildTaints();
    public V1Taint buildTaint(int index);
    public V1Taint buildFirstTaint();
    public V1Taint buildLastTaint();
    public V1Taint buildMatchingTaint(io.kubernetes.client.fluent.Predicate<V1TaintBuilder> predicate);
    public Boolean hasMatchingTaint(io.kubernetes.client.fluent.Predicate<V1TaintBuilder> predicate);
    public A withTaints(List<V1Taint> taints);
    public A withTaints(V1Taint... taints);
    public Boolean hasTaints();
    public V1NodeSpecFluent.TaintsNested<A> addNewTaint();
    public V1NodeSpecFluent.TaintsNested<A> addNewTaintLike(V1Taint item);
    public V1NodeSpecFluent.TaintsNested<A> setNewTaintLike(int index,V1Taint item);
    public V1NodeSpecFluent.TaintsNested<A> editTaint(int index);
    public V1NodeSpecFluent.TaintsNested<A> editFirstTaint();
    public V1NodeSpecFluent.TaintsNested<A> editLastTaint();
    public V1NodeSpecFluent.TaintsNested<A> editMatchingTaint(io.kubernetes.client.fluent.Predicate<V1TaintBuilder> predicate);
    public Boolean isUnschedulable();
    public A withUnschedulable(Boolean unschedulable);
    public Boolean hasUnschedulable();
    public A withNewUnschedulable(String arg1);
    public A withNewUnschedulable(boolean arg1);

    public interface ConfigSourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeConfigSourceFluent<V1NodeSpecFluent.ConfigSourceNested<N>>{

        
    public N and();    public N endConfigSource();
}
    public interface TaintsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TaintFluent<V1NodeSpecFluent.TaintsNested<N>>{

        
    public N and();    public N endTaint();
}


}
